@@ -8,5 +8,6 @@ class SubscriptionEstimate(Model):
       fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
       pass
 
-    fields = ["id", "currency_code", "status", "next_billing_at", "shipping_address"]
+    fields = ["id", "currency_code", "status", "next_billing_at", "pause_date", "resume_date", \
+    "shipping_address"]
 
